{% load i18n lfs_theme_tags %}
<html>
    <head>
        {% include "lfs/mail/mail.css" %}
    </head>
    <body>
        <p>
            {% blocktrans with firstname=order.customer_firstname lastname=order.customer_lastname %}Dear {{ firstname }} {{ lastname }}{% endblocktrans %},
        </p>
        <p>
            {% trans "your order has been received." %}
        </p>
        <p>
            {% include "lfs/mail/order_details.html" %}
        </p>
        {% email_html_footer %}
    </body>
</html>
