{% load i18n lfs_tags %}

<div class="cart-portlet portlet">

    <div class="portlet-header">
        {% if title %}
            <a href="{% url lfs.cart.views.cart %}"
               title="{% trans 'Go to cart' %}">{{ title }}
        {% else %}
            {% trans 'Cart' %}
        {% endif %}
        <img src="{{ STATIC_URL }}img/cart.png"
             alt="{% trans 'Cart' %}" />
        </a>
    </div>

    <div class="portlet-body">
        {% if amount_of_items_int %}
            <div class="article">
                {% blocktrans with amount=amount_of_items_locale count counter=amount_of_items_int %}{{ amount }} Article{% plural %}{{ amount }} Articles{% endblocktrans %}
            </div>
            <div class="price">
                {{ price|currency:request }}
            </div>
        {% else %}
            {% trans 'Cart is empty' %}
        {% endif %}
    </div>

    <div class="portlet-footer">
        <a href="{% url lfs.cart.views.cart %}">
            {% trans 'Go to cart' %}
        </a>
    </div>

</div>
