{% extends "lfs/base.html" %}
{% load i18n %}

{% block title %}{% trans 'Password reset complete' %}{% endblock %}
{% block section %}password-reset-complete{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumbs">
        <li>{% trans 'You are here:' %}</li>
        <li>
            <a href="{% url lfs_shop_view %}">
                {% trans 'Home' %}</a> &gt;
        </li>
        <li>
            {% trans "Password reset" %}
        </li>
    </ul>
{% endblock %}

{% block content %}
    <h1 class="first-heading">
        {% trans 'Password reset complete' %}
    </h1>
    <p>
        {% trans "Your password has been set. You may go ahead and log in now." %}
    </p>
    <p class="buttons">
        <a href="{{ login_url }}?next={% url lfs_shop_view %}">{% trans 'Log in' %}</a>
    </p>
{% endblock %}
