{% load i18n %}<style type="text/css">div.footer{color:#888888;font-style: italic;margin-top:10px;}</style><div class="footer">------<br />
{% blocktrans with shop.name as name %}This e-mail was sent automatically from {{ name }}{% endblocktrans %}
</div>