{% load i18n lfs_theme_tags %}
<html>
    <head>
        {% include "lfs/mail/mail.css" %}
    </head>
    <body>
        <h1>{% trans 'Welcome to' %} {{ shop.name }}</h1>
        <p>
            {% trans "Thank you for registering" %}
        </p>
        <p>
            {% trans "Your username" %}: {{ user.username }}
        </p>

        {% email_html_footer %}
    </body>
</html>