{% extends "lfs/customer/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block section %}my-account{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _("Your Account") %}
{% endblock %}

{% block content %}
<h1>{% trans "Welcome!" %}</h1>

{% trans "Welcome to your account. Here you can find your orders, you can change your addresses, email address and your password." %}

{% endblock %}
